@@ -13,7 +13,7 @@ use Test::Stream::Util qw/try/;
 use Test::Stream::Meta qw/init_tester is_tester/;
 
 use Test::Stream::ArrayBase(
-    accessors => [qw/frame stream encoding in_todo todo modern pid skip diag_todo provider/],
+    accessors => [qw/frame stream encoding in_todo todo modern pid skip diag_todo provider monkeypatch_stash/],
 );
 
 use Test::Stream::Exporter qw/import export_to default_exports/;
@@ -175,10 +175,6 @@ sub _find_tester {
     return init_tester('main');
 }
 
-sub done_testing {
-    $_[0]->stream->done_testing(@_);
-}
-
 sub alert {
     my $self = shift;
     my ($msg) = @_;
@@ -215,11 +211,57 @@ sub send {
     $self->[STREAM]->send(@_);
 }
 
+# Uhg.. support legacy monkeypatching
+# If this is still here in 2020 I will be a sad panda.
+{
+    sub ok {
+        return _ok(@_) unless $INC{'Test/Builder.pm'} && $Test::Builder::ORIG{ok} != \&Test::Builder::ok;
+        my $self = shift;
+        local $Test::Builder::CTX = $self;
+        my ($bool, $name, @stash) = @_;
+        push @{$self->[MONKEYPATCH_STASH]} => \@stash;
+        my $out = Test::Builder->new->ok($bool, $name);
+        return $out;
+    }
+
+    sub _unwind_ok {
+        my $self = shift;
+        my ($bool, $name) = @_;
+        my $stash = pop @{$self->[MONKEYPATCH_STASH]};
+        return $self->_ok($bool, $name, @$stash);
+    }
+
+    sub note {
+        return _note(@_) unless $INC{'Test/Builder.pm'} && $Test::Builder::ORIG{note} != \&Test::Builder::note;
+        local $Test::Builder::CTX = shift;
+        my $out = Test::Builder->new->note(@_);
+        return $out;
+    }
+
+    sub diag {
+        return _diag(@_) unless $INC{'Test/Builder.pm'} && $Test::Builder::ORIG{diag} != \&Test::Builder::diag;
+        local $Test::Builder::CTX = shift;
+        my $out = Test::Builder->new->diag(@_);
+        return $out;
+    }
+
+    sub done_testing {
+        return $_[0]->stream->done_testing(@_)
+            unless $INC{'Test/Builder.pm'} && $Test::Builder::ORIG{done_testing} != \&Test::Builder::done_testing;
+
+        local $Test::Builder::CTX = shift;
+        my $out = Test::Builder->new->done_testing(@_);
+        return $out;
+    }
+}
+
 sub register_event {
     my $class = shift;
-    my ($pkg) = @_;
-    my $name = lc($pkg);
-    $name =~ s/^.*:://g;
+    my ($pkg, $name) = @_;
+    unless($name) {
+        $name = lc($pkg);
+        $name =~ s/^.*:://g;
+    }
 
     confess "Method '$name' is already defined, event '$pkg' cannot get a context method!"
         if $class->can($name);
